@@ -8,8 +8,6 @@ import pytz
 import json
 import io
 
-# TODO testing
-
 
 def bq_to_df(sql, client=None, **job_config):
     """Return bigquery query result as pandas.DataFrame.
@@ -387,7 +385,7 @@ def df_to_bq(df, table_id, client=None, write_mode='WRITE_APPEND', schema=None,
     return load_job
 
 
-def df_to_bq_with_json_objects(df, table_id, client=None, schema=None, json_str_column=None, write_mode='WRITE_APPEND',  **job_config):
+def df_to_bq_with_json_objects(df, table_id, client=None, schema=None, json_str_column=None, write_mode='WRITE_APPEND', job_id=None, **job_config):
     """Write DataFrame to bigquery with nested and repeated fields or JSON objects.
 
     Arguments:
@@ -456,10 +454,10 @@ def df_to_bq_with_json_objects(df, table_id, client=None, schema=None, json_str_
     if json_str_column:
         if isinstance(json_str_column, list):
             for column in json_str_column:
-                df[column] = df[column].apply(json_obj_to_str)
+                df[column] = df[column].apply(json.dumps)
         else:
             column = json_str_column
-            df[column] = df[column].apply(json_obj_to_str)
+            df[column] = df[column].apply(json.dumps)
 
     # ,date_format='%Y-%m-%dT%H:%M:%S.%f'
     buffer = StringIO(df.to_json(orient="records", lines=True))
@@ -474,7 +472,7 @@ def df_to_bq_with_json_objects(df, table_id, client=None, schema=None, json_str_
 
     logging.debug(f'Load job config: \n {job_config.to_api_repr()}')
     load_job = client.load_table_from_file(
-        buffer, table_id, job_config=job_config)
+        buffer, table_id, job_id=job_id, job_config=job_config)
     return load_job
 
 
@@ -984,7 +982,7 @@ def get_gcp_service_account(credentials, storage_client=None):
                 storage_client = storage.Client()
 
             credentials = gcs_download_blob(
-                credentials, output_option='CREDENTIALS') #dependency
+                credentials, output_option='CREDENTIALS')  # dependency
             logging.debug(
                 f"project_id: {credentials.project_id} service_account_email: {credentials.service_account_email}")
         else:
